@@ -9,6 +9,7 @@ from .debugger import stresstest
 API_KEY = '2aaf98e1-4dd6-4353-a88c-0051be97821a' 
 app = Flask(__name__)
 
+
 # Index route
 @app.route('/')
 def home():
@@ -54,6 +55,39 @@ def showRows():
     return resp
 
 
+# Reading 4 files (generator, checker, correct, wrong) which contain respectively:
+# generator: a .cpp file containing a generator of a test case
+# checker: a .cpp file containing a checker in order to see
+#          if the wrong solution has the same result of the correct one
+# correct: a .cpp file containing a solution that should be correct
+#          for every test case
+# wrong: a .cpp file containing a possible solution (we don't know whether
+#        it works for every test case or not)
+#
+# The method returns the test_id of the stress-test in the database
+# and the debugger result obtained by these files.
+@app.route('/sub', methods=["POST"])
+def exec_sub():
+    # reading input and formatting in order to 
+    # execute the submit method
+    cpp_files = [request.files['generator'].read().decode('utf-8'),
+                 request.files['checker'].read().decode('utf-8'),
+                 request.files['correct'].read().decode('utf-8'),
+                 request.files['wrong'].read().decode('utf-8')]
+    safety = request.form['safety'] == "True"
+    testcase = int(request.form['testcase'])
+    timelimit = float(request.form['timelimit'])
+
+    # executing the stresstest and the submit
+    test_id, dbg_res = submit(cpp_files, safety, testcase, timelimit)
+
+    # setting response's output
+    resp = Response(json.dumps({'id' : test_id,
+                                'result' : dbg_res}))
+    resp.mimetype = "application/json"
+    return resp
+
+
 # Executes the stresstest and submit the result in the database
 # cpp_files[0]: string
 #               generator.cpp string
@@ -99,9 +133,10 @@ def submit(cpp_files, safety, testcase, timelimit):
     with open('wrong.cpp', 'w', encoding='utf-8') as out_wrong:
         subprocess.run(['echo', cpp_files[3]], stdout=out_wrong, check=False)
 
+    
     # executing stress-test 
     dbg_res = stresstest(safety, testcase, timelimit)
-
+    
     # updating test row adding tester's result
     cur.execute("UPDATE submission SET result = %s WHERE test_id = %s ;",
                 (str(dbg_res), str(test_id)))
@@ -110,18 +145,9 @@ def submit(cpp_files, safety, testcase, timelimit):
     conn.commit()
 
     # deleting temporary files and directory
-    subprocess.call(['rm', 'generator.cpp'])
-    subprocess.call(['rm', 'checker.cpp'])
-    subprocess.call(['rm', 'correct.cpp'])
-    subprocess.call(['rm', 'wrong.cpp'])
-    subprocess.call(['rm', 'log.txt'])
-    if dbg_res != 0:
-        subprocess.call(['rm', 'results/input.txt'])
-        subprocess.call(['rm', 'results/correct_output.txt'])
-        subprocess.call(['rm', 'results/wrong_output.txt'])
-        subprocess.call(['rm', '-d', 'results'])
     os.chdir('../')
-    subprocess.call(['rm', '-d', f'id_{test_id}/'])
+    subprocess.call(['rm', '-r', f'id_{test_id}/'])
+    
     return (test_id, dbg_res)
     
     
@@ -142,39 +168,6 @@ def getSub(subid):
     return row
 
 
-
-# Reading 4 files (generator, checker, correct, wrong) which contain respectively:
-# generator: a .cpp file containing a generator of a test case
-# checker: a .cpp file containing a checker in order to see
-#          if the wrong solution has the same result of the correct one
-# correct: a .cpp file containing a solution that should be correct
-#          for every test case
-# wrong: a .cpp file containing a possible solution (we don't know whether
-#        it works for every test case or not)
-#
-# The method returns the test_id of the stress-test in the database
-# and the debugger result obtained by these files.
-@app.route('/sub', methods=["POST"])
-def exec_sub():
-    # reading input and formatting in order to 
-    # execute the submit method
-    cpp_files = [request.files['generator'].read().decode('utf-8'),
-                 request.files['checker'].read().decode('utf-8'),
-                 request.files['correct'].read().decode('utf-8'),
-                 request.files['wrong'].read().decode('utf-8')]
-    safety = request.form['safety'] == "True"
-    testcase = int(request.form['testcase'])
-    timelimit = float(request.form['timelimit'])
-
-    # executing the stresstest and the submit
-    test_id, dbg_res = submit(cpp_files, safety, testcase, timelimit)
-
-    # setting response's output
-    resp = Response(json.dumps({'id' : test_id,
-                                'result' : dbg_res}))
-    resp.mimetype = "application/json"
-    return resp
-
-
-if __name__ == "main":
-    app.run(debug=False)
+if __name__ == '__main__':
+    port = int(os.environ.get("PORT", 5000))
+    app.run(debug=False, host='0.0.0.0', port=port)
