@@ -1,6 +1,3 @@
-import multiprocessing as mp
-from multiprocessing import Pool
-from itertools import repeat
 import subprocess
 import random
 import os
@@ -23,12 +20,13 @@ def compile_cpp(cpp, binary, safe=False):
     compilation_process = 1
     if safe:
         compilation_process = subprocess.run(
-            ['gcc', '-o', binary, cpp, '-lstdc++', '-g', '-fsanitize=address', '-fsanitize=undefined', '-std=c++17', '-Wall', '-D_GLIBCXX_DEBUG'],
+            ['g++', '-std=c++17', '-Wshadow', '-Wall', '-o', binary, cpp, '-g', '-fsanitize=address','-fsanitize=undefined', '-D_GLIBCXX_DEBUG'],
             capture_output=True,
             text=True,
             check=False)
     else:
-        compilation_process = subprocess.run(['gcc', '-o', binary, cpp, '-lstdc++'],
+        compilation_process = subprocess.run(
+            ['g++', '-o', binary, cpp],
             capture_output=True,
             text=True,
             check=False)
@@ -46,21 +44,17 @@ def compile_cpp(cpp, binary, safe=False):
 #       5 Wrong output produced
 #       6 Another worker already finished
 
-def worker(name, test_cases, time_limit, done):
+def worker(name, test_cases, time_limit):
     current_folder = 'files/worker' + str(name) + '/'
     subprocess.call(['mkdir', '-p', current_folder])
     subprocess.call(['cp', '-t', current_folder, 'gen', 'checker', 'wrong', 'correct'])
     for _ in range(test_cases):
-        # If a counter example has already been founded stop here
-        if done.is_set():
-            return 6
 
         # Run generator
         seed = random.randint(1, 1000000000)
         with open(current_folder + 'input.txt', 'w+', encoding='utf-8') as output_file, open('log.txt', 'w+', encoding='utf-8') as err_file:
             gen_execution = subprocess.run([current_folder + 'gen', str(seed)], stdout=output_file, stderr=err_file, check=False)
         if gen_execution.returncode != 0:
-            done.set()
             return 1
 
         # Run correct solution
@@ -69,7 +63,6 @@ def worker(name, test_cases, time_limit, done):
                 open('log.txt', 'w+', encoding='utf-8') as err_file:
             correct_execution = subprocess.run(current_folder + 'correct', stdin=input_file, stdout=output_file, stderr=err_file, text=True, check=False)
         if correct_execution.returncode != 0:
-            done.set()
             return 2 
 
         # Run wrong solution
@@ -80,12 +73,8 @@ def worker(name, test_cases, time_limit, done):
                 wrong_solution = subprocess.run(current_folder + 'wrong', stdin=input_file, 
                         stdout=output_file, stderr=err_file, text=True, timeout=time_limit, check=False)
             if wrong_solution.returncode != 0:
-                done.set()
                 return 3
         except subprocess.TimeoutExpired:
-            if done.is_set():
-                return 6
-            done.set()
             clear_dir('results')
             subprocess.call(['mkdir', '-p', 'results'])
             subprocess.call(['cp', current_folder + 'input.txt', 'results/'])
@@ -95,9 +84,6 @@ def worker(name, test_cases, time_limit, done):
         # Run checker
         check_execution = subprocess.run([current_folder + 'checker', current_folder + 'correct_output.txt', current_folder + 'wrong_output.txt'], check=False)
         if check_execution.returncode != 0:
-            if done.is_set():
-                return 6
-            done.set()
             clear_dir('results')
             subprocess.call(['mkdir', '-p', 'results'])
             subprocess.call(['cp', current_folder + 'input.txt', 'results/'])
@@ -109,13 +95,8 @@ def worker(name, test_cases, time_limit, done):
 def execute(test_cases, time_limit):
     clear_dir('results')
     clear_files(['log.txt'])
-    workers = mp.cpu_count() 
-    tcs = [test_cases // workers + (1 if i < test_cases % workers else 0) for i in range(workers)]
-    with Pool(processes=workers) as pool:
-        names = range(workers)
-        manager = mp.Manager()
-        event = manager.Event()
-        results = pool.starmap(worker, zip(names, tcs, repeat(time_limit), repeat(event)))
+    workers = 1
+    results = [worker(1, test_cases, time_limit)]
     clear_files(['wrong', 'gen', 'checker', 'correct'])
     clear_dir('files')
     # No counter example founded
